@@ -16,13 +16,8 @@ import urllib.parse
 import keystoneauth1.exceptions
 
 from openstack.cloud import _utils
+from openstack.cloud import openstackcloud
 from openstack import exceptions
-from openstack.object_store.v1._proxy import Proxy
-
-DEFAULT_OBJECT_SEGMENT_SIZE = 1073741824  # 1GB
-# This halves the current default for Swift
-DEFAULT_MAX_FILE_SIZE = (5 * 1024 * 1024 * 1024 + 2) / 2
-
 
 OBJECT_CONTAINER_ACLS = {
     'public': '.r:*,.rlistings',
@@ -30,8 +25,7 @@ OBJECT_CONTAINER_ACLS = {
 }
 
 
-class ObjectStoreCloudMixin:
-    object_store: Proxy
+class ObjectStoreCloudMixin(openstackcloud._OpenStackCloudMixin):
 
     # TODO(stephenfin): Remove 'full_listing' as it's a noop
     def list_containers(self, full_listing=True, prefix=None):
@@ -456,7 +450,7 @@ class ObjectStoreCloudMixin:
             yield from self.object_store.stream_object(
                 obj, container, chunk_size=resp_chunk_size
             )
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             return
 
     def get_object(
@@ -498,7 +492,7 @@ class ObjectStoreCloudMixin:
             headers = {k.lower(): v for k, v in obj._last_headers.items()}
             return (headers, obj.data)
 
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             return None
 
     def _wait_for_futures(self, futures, raise_on_error=True):
