@@ -270,35 +270,29 @@ try to find it and if that fails, you would create it::
 Additional information about the services can be found in the
 :ref:`service-proxies` documentation.
 """
-import atexit
-import concurrent.futures
+
+import copy
 import importlib.metadata as importlib_metadata
 import warnings
-import weakref
 
 import keystoneauth1.exceptions
 import requestsexceptions
 
 from openstack import _log
-from openstack import _services_mixin
 from openstack.cloud import _accelerator
 from openstack.cloud import _baremetal
 from openstack.cloud import _block_storage
 from openstack.cloud import _coe
 from openstack.cloud import _compute
 from openstack.cloud import _dns
-from openstack.cloud import _floating_ip
 from openstack.cloud import _identity
 from openstack.cloud import _image
 from openstack.cloud import _network
-from openstack.cloud import _network_common
 from openstack.cloud import _object_store
 from openstack.cloud import _orchestration
-from openstack.cloud import _security_group
 from openstack.cloud import _shared_file_system
-from openstack.cloud import openstackcloud as _cloud
 from openstack import config as _config
-from openstack.config import cloud_region
+import openstack.config.cloud_region
 from openstack import exceptions
 from openstack import service_description
 
@@ -346,22 +340,17 @@ def from_config(cloud=None, config=None, options=None, **kwargs):
 
 
 class Connection(
-    _services_mixin.ServicesMixin,
-    _cloud._OpenStackCloudMixin,
     _accelerator.AcceleratorCloudMixin,
     _baremetal.BaremetalCloudMixin,
     _block_storage.BlockStorageCloudMixin,
     _compute.ComputeCloudMixin,
     _coe.CoeCloudMixin,
     _dns.DnsCloudMixin,
-    _floating_ip.FloatingIPCloudMixin,
     _identity.IdentityCloudMixin,
     _image.ImageCloudMixin,
     _network.NetworkCloudMixin,
-    _network_common.NetworkCommonCloudMixin,
     _object_store.ObjectStoreCloudMixin,
     _orchestration.OrchestrationCloudMixin,
-    _security_group.SecurityGroupCloudMixin,
     _shared_file_system.SharedFileSystemCloudMixin,
 ):
     def __init__(
@@ -373,7 +362,7 @@ class Connection(
         app_version=None,
         extra_services=None,
         strict=False,
-        use_direct_get=False,
+        use_direct_get=None,
         task_manager=None,
         rate_limit=None,
         oslo_conf=None,
@@ -381,7 +370,7 @@ class Connection(
         global_request_id=None,
         strict_proxies=False,
         pool_executor=None,
-        **kwargs
+        **kwargs,
     ):
         """Create a connection to a cloud.
 
@@ -428,97 +417,53 @@ class Connection(
             keys as service-type and values as floats expressing the calls
             per second for that service. Defaults to None, which means no
             rate-limiting is performed.
-        :param oslo_conf: An oslo.config CONF object.
-        :type oslo_conf: :class:`~oslo_config.cfg.ConfigOpts`
-            An oslo.config ``CONF`` object that has been populated with
+        :param oslo_conf: An oslo.config ``CONF`` object that has been
+            populated with
             ``keystoneauth1.loading.register_adapter_conf_options`` in
             groups named by the OpenStack service's project name.
+        :type oslo_conf: :class:`~oslo_config.cfg.ConfigOpts`
         :param service_types:
             A list/set of service types this Connection should support. All
             other service types will be disabled (will error if used).
             **Currently only supported in conjunction with the ``oslo_conf``
             kwarg.**
-        :param global_request_id: A Request-id to send with all interactions.
         :param strict_proxies:
-            If True, check proxies on creation and raise
-            ServiceDiscoveryException if the service is unavailable.
-        :type strict_proxies: bool
             Throw an ``openstack.exceptions.ServiceDiscoveryException`` if the
             endpoint for a given service doesn't work. This is useful for
             OpenStack services using sdk to talk to other OpenStack services
             where it can be expected that the deployer config is correct and
             errors should be reported immediately.
             Default false.
+        :type strict_proxies: bool
+        :param global_request_id: A Request-id to send with all interactions.
+        :type global_request_id: str
         :param pool_executor:
-        :type pool_executor: :class:`~futurist.Executor`
             A futurist ``Executor`` object to be used for concurrent background
             activities. Defaults to None in which case a ThreadPoolExecutor
             will be created if needed.
+        :type pool_executor: :class:`~futurist.Executor`
         :param kwargs: If a config is not provided, the rest of the parameters
             provided are assumed to be arguments to be passed to the
             CloudRegion constructor.
         """
-        self.config = config
-        self._extra_services = {}
-        self._strict_proxies = strict_proxies
-        if extra_services:
-            for service in extra_services:
-                self._extra_services[service.service_type] = service
-
-        if not self.config:
-            if oslo_conf:
-                self.config = cloud_region.from_conf(
-                    oslo_conf,
-                    session=session,
-                    app_name=app_name,
-                    app_version=app_version,
-                    service_types=service_types,
-                )
-            elif session:
-                self.config = cloud_region.from_session(
-                    session=session,
-                    app_name=app_name,
-                    app_version=app_version,
-                    load_yaml_config=False,
-                    load_envvars=False,
-                    rate_limit=rate_limit,
-                    **kwargs
-                )
-            else:
-                self.config = _config.get_cloud_region(
-                    cloud=cloud,
-                    app_name=app_name,
-                    app_version=app_version,
-                    load_yaml_config=cloud is not None,
-                    load_envvars=cloud is not None,
-                    rate_limit=rate_limit,
-                    **kwargs
-                )
-
-        self._session = None
-        self._proxies = {}
-        self.__pool_executor = pool_executor
-        self._global_request_id = global_request_id
-        self.use_direct_get = use_direct_get
-        self.strict_mode = strict
-        # Call the _*CloudMixin constructors while we work on
-        # integrating things better.
-        _cloud._OpenStackCloudMixin.__init__(self)
-        _accelerator.AcceleratorCloudMixin.__init__(self)
-        _baremetal.BaremetalCloudMixin.__init__(self)
-        _block_storage.BlockStorageCloudMixin.__init__(self)
-        _coe.CoeCloudMixin.__init__(self)
-        _compute.ComputeCloudMixin.__init__(self)
-        _dns.DnsCloudMixin.__init__(self)
-        _floating_ip.FloatingIPCloudMixin.__init__(self)
-        _identity.IdentityCloudMixin.__init__(self)
-        _image.ImageCloudMixin.__init__(self)
-        _network_common.NetworkCommonCloudMixin.__init__(self)
-        _network.NetworkCloudMixin.__init__(self)
-        _object_store.ObjectStoreCloudMixin.__init__(self)
-        _orchestration.OrchestrationCloudMixin.__init__(self)
-        _security_group.SecurityGroupCloudMixin.__init__(self)
-        _shared_file_system.SharedFileSystemCloudMixin.__init__(self)
+        super().__init__(
+            cloud=cloud,
+            config=config,
+            session=session,
+            app_name=app_name,
+            app_version=app_version,
+            extra_services=extra_services,
+            strict=strict,
+            use_direct_get=use_direct_get,
+            task_manager=task_manager,
+            rate_limit=rate_limit,
+            oslo_conf=oslo_conf,
+            service_types=service_types,
+            global_request_id=global_request_id,
+            strict_proxies=strict_proxies,
+            pool_executor=pool_executor,
+            **kwargs,
+        )
 
         # Allow vendors to provide hooks. They will normally only receive a
         # connection object and a responsible to register additional services
@@ -531,7 +476,7 @@ class Connection(
                 # NOTE(gtema): no class name in the hook, plain module:function
                 # Split string hook into module and function
                 try:
-                    (package_name, function) = vendor_hook.rsplit(':')
+                    package_name, function = vendor_hook.rsplit(':')
 
                     if package_name and function:
                         ep = importlib_metadata.EntryPoint(
@@ -562,19 +507,6 @@ class Connection(
                 self.config.config['additional_metric_tags']
             )
 
-        # Register cleanup steps
-        atexit.register(self.close)
-
-    @property
-    def session(self):
-        if not self._session:
-            self._session = self.config.get_session()
-            # Hide a reference to the connection on the session to help with
-            # backwards compatibility for folks trying to just pass
-            # conn.session to a Resource method's session argument.
-            self.session._sdk_connection = weakref.proxy(self)
-        return self._session
-
     def add_service(self, service):
         """Add a service to the Connection.
 
@@ -614,42 +546,148 @@ class Connection(
     def authorize(self):
         """Authorize this Connection
 
-        .. note:: This method is optional. When an application makes a call
-                  to any OpenStack service, this method allows you to request
-                  a token manually before attempting to do anything else.
+        .. note::
+
+            This method is optional. When an application makes a call to any
+            OpenStack service, this method allows you to request a token
+            manually before attempting to do anything else.
 
         :returns: A string token.
-
         :raises: :class:`~openstack.exceptions.HttpException` if the
-                 authorization fails due to reasons like the credentials
-                 provided are unable to be authorized or the `auth_type`
-                 argument is missing, etc.
+            authorization fails due to reasons like the credentials
+            provided are unable to be authorized or the `auth_type`
+            argument is missing, etc.
         """
         try:
             return self.session.get_token()
         except keystoneauth1.exceptions.ClientException as e:
             raise exceptions.SDKException(e)
 
-    @property
-    def _pool_executor(self):
-        if not self.__pool_executor:
-            self.__pool_executor = concurrent.futures.ThreadPoolExecutor(
-                max_workers=5
+    def connect_as(self, **kwargs):
+        """Make a new Connection object with new auth context.
+
+        Take the existing settings from the current cloud and construct a new
+        Connection object with some of the auth settings overridden. This
+        is useful for getting an object to perform tasks with as another user,
+        or in the context of a different project.
+
+        .. code-block:: python
+
+            conn = openstack.connect(cloud='example')
+            # Work normally
+            servers = conn.list_servers()
+            conn2 = conn.connect_as(username='different-user', password='')
+            # Work as different-user
+            servers = conn2.list_servers()
+
+        :param kwargs: keyword arguments can contain anything that would
+            normally go in an auth dict. They will override the same settings
+            from the parent cloud as appropriate. Entries that do not want to
+            be overridden can be ommitted.
+        """
+
+        if self.config._openstack_config:
+            config = self.config._openstack_config
+        else:
+            # TODO(mordred) Replace this with from_session
+            config = openstack.config.OpenStackConfig(
+                app_name=self.config._app_name,
+                app_version=self.config._app_version,
+                load_yaml_config=False,
             )
-        return self.__pool_executor
+        params = copy.deepcopy(self.config.config)
+        # Remove profile from current cloud so that overridding works
+        params.pop('profile', None)
 
-    def close(self):
-        """Release any resources held open."""
-        self.config.set_auth_cache()
-        if self.__pool_executor:
-            self.__pool_executor.shutdown()
-        atexit.unregister(self.close)
+        # Utility function to help with the stripping below.
+        def pop_keys(params, auth, name_key, id_key):
+            if name_key in auth or id_key in auth:
+                params['auth'].pop(name_key, None)
+                params['auth'].pop(id_key, None)
 
-    def set_global_request_id(self, global_request_id):
-        self._global_request_id = global_request_id
+        # If there are user, project or domain settings in the incoming auth
+        # dict, strip out both id and name so that a user can say:
+        #     cloud.connect_as(project_name='foo')
+        # and have that work with clouds that have a project_id set in their
+        # config.
+        for prefix in ('user', 'project'):
+            if prefix == 'user':
+                name_key = 'username'
+            else:
+                name_key = 'project_name'
+            id_key = f'{prefix}_id'
+            pop_keys(params, kwargs, name_key, id_key)
+            id_key = f'{prefix}_domain_id'
+            name_key = f'{prefix}_domain_name'
+            pop_keys(params, kwargs, name_key, id_key)
 
-    def __enter__(self):
-        return self
+        for key, value in kwargs.items():
+            params['auth'][key] = value
 
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.close()
+        cloud_region = config.get_one(**params)
+        # Attach the discovery cache from the old session so we won't
+        # double discover.
+        cloud_region._discovery_cache = self.session._discovery_cache
+        # Override the cloud name so that logging/location work right
+        cloud_region._name = self.name
+        cloud_region.config['profile'] = self.name
+        # Use self.__class__ so that we return whatever this if, like if it's
+        # a subclass in the case of shade wrapping sdk.
+        return self.__class__(config=cloud_region)
+
+    def connect_as_project(self, project):
+        """Make a new Connection object with a new project.
+
+        Take the existing settings from the current cloud and construct a new
+        Connection object with the project settings overridden. This
+        is useful for getting an object to perform tasks with as another user,
+        or in the context of a different project.
+
+        .. code-block:: python
+
+            cloud = openstack.connect(cloud='example')
+            # Work normally
+            servers = cloud.list_servers()
+            cloud2 = cloud.connect_as_project('different-project')
+            # Work in different-project
+            servers = cloud2.list_servers()
+
+        :param project: Either a project name or a project dict as returned by
+            ``list_projects``.
+        """
+        auth = {}
+        if isinstance(project, dict):
+            auth['project_id'] = project.get('id')
+            auth['project_name'] = project.get('name')
+            if project.get('domain_id'):
+                auth['project_domain_id'] = project['domain_id']
+        else:
+            auth['project_name'] = project
+        return self.connect_as(**auth)
+
+    def endpoint_for(self, service_type, interface=None, region_name=None):
+        """Return the endpoint for a given service.
+
+        Respects config values for Connection, including
+        ``*_endpoint_override``. For direct values from the catalog regardless
+        of overrides, see
+        :meth:`~openstack.config.cloud_region.CloudRegion.get_endpoint_from_catalog`
+
+        :param service_type: Service Type of the endpoint to search for.
+        :param interface: Interface of the endpoint to search for. Optional,
+            defaults to the configured value for interface for this Connection.
+        :param region_name: Region Name of the endpoint to search for.
+            Optional, defaults to the configured value for region_name for this
+            Connection.
+
+        :returns: The endpoint of the service, or None if not found.
+        """
+
+        endpoint_override = self.config.get_endpoint(service_type)
+        if endpoint_override:
+            return endpoint_override
+        return self.config.get_endpoint_from_catalog(
+            service_type=service_type,
+            interface=interface,
+            region_name=region_name,
+        )
