@@ -64,6 +64,7 @@ from openstack.network.v2 import service_profile
 from openstack.network.v2 import service_provider
 from openstack.network.v2 import subnet
 from openstack.network.v2 import subnet_pool
+from openstack.network.v2 import tap_mirror
 from openstack.network.v2 import vpn_endpoint_group
 from openstack.network.v2 import vpn_ike_policy
 from openstack.network.v2 import vpn_ipsec_policy
@@ -86,7 +87,7 @@ BGPVPN_ID = 'bgpvpn-id-' + uuid.uuid4().hex
 
 class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
-        super(TestNetworkProxy, self).setUp()
+        super().setUp()
         self.proxy = _proxy.Proxy(self.session)
 
     def verify_update(
@@ -1511,6 +1512,48 @@ class TestNetworkRouter(TestNetworkProxy):
         )
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
+    @mock.patch.object(router.Router, 'add_external_gateways')
+    def test_add_external_gateways(self, mock_add, mock_get):
+        x_router = router.Router.new(id="ROUTER_ID")
+        mock_get.return_value = x_router
+
+        self._verify(
+            "openstack.network.v2.router.Router.add_external_gateways",
+            self.proxy.add_external_gateways,
+            method_args=["FAKE_ROUTER", "bar"],
+            expected_args=[self.proxy, "bar"],
+        )
+        mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
+
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
+    @mock.patch.object(router.Router, 'update_external_gateways')
+    def test_update_external_gateways(self, mock_remove, mock_get):
+        x_router = router.Router.new(id="ROUTER_ID")
+        mock_get.return_value = x_router
+
+        self._verify(
+            "openstack.network.v2.router.Router.update_external_gateways",
+            self.proxy.update_external_gateways,
+            method_args=["FAKE_ROUTER", "bar"],
+            expected_args=[self.proxy, "bar"],
+        )
+        mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
+
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
+    @mock.patch.object(router.Router, 'remove_external_gateways')
+    def test_remove_external_gateways(self, mock_remove, mock_get):
+        x_router = router.Router.new(id="ROUTER_ID")
+        mock_get.return_value = x_router
+
+        self._verify(
+            "openstack.network.v2.router.Router.remove_external_gateways",
+            self.proxy.remove_external_gateways,
+            method_args=["FAKE_ROUTER", "bar"],
+            expected_args=[self.proxy, "bar"],
+        )
+        mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
+
     def test_router_hosting_l3_agents_list(self):
         self.verify_list(
             self.proxy.routers_hosting_l3_agents,
@@ -2596,3 +2639,30 @@ class TestNetworkBGPVPN(TestNetworkProxy):
             expected_args=[self.ROUTER_ASSOCIATION],
             expected_kwargs={'bgpvpn_id': BGPVPN_ID},
         )
+
+
+class TestNetworkTapMirror(TestNetworkProxy):
+    def test_create_tap_mirror(self):
+        self.verify_create(self.proxy.create_tap_mirror, tap_mirror.TapMirror)
+
+    def test_delete_tap_mirror(self):
+        self.verify_delete(
+            self.proxy.delete_tap_mirror, tap_mirror.TapMirror, False
+        )
+
+    def test_delete_tap_mirror_ignore(self):
+        self.verify_delete(
+            self.proxy.delete_tap_mirror, tap_mirror.TapMirror, True
+        )
+
+    def test_find_tap_mirror(self):
+        self.verify_find(self.proxy.find_tap_mirror, tap_mirror.TapMirror)
+
+    def test_get_tap_mirror(self):
+        self.verify_get(self.proxy.get_tap_mirror, tap_mirror.TapMirror)
+
+    def test_tap_mirrors(self):
+        self.verify_list(self.proxy.tap_mirrors, tap_mirror.TapMirror)
+
+    def test_update_tap_mirror(self):
+        self.verify_update(self.proxy.update_tap_mirror, tap_mirror.TapMirror)
